@@ -16,16 +16,12 @@ import (
 
 	"github.com/apex/log"
 	"github.com/apex/log/handlers/cli"
-	"github.com/vbauerster/mpb/v7"
-	"github.com/vbauerster/mpb/v7/decor"
+	"github.com/vbauerster/mpb/v8"
+	"github.com/vbauerster/mpb/v8/decor"
 )
 
 var normalPadding = cli.Default.Padding
 
-func init() {
-	rand.Seed(time.Now().Unix())
-}
-
 // Retry will retry a function f a number of attempts with a sleep duration in between
 func Retry(attempts int, sleep time.Duration, f func() error) (err error) {
 	for i := 0; i < attempts; i++ {
@@ -230,7 +226,7 @@ func SearchZip(files []*zip.File, pattern *regexp.Regexp, folder string, flat, p
 						mpb.AppendDecorators(
 							decor.OnComplete(decor.AverageETA(decor.ET_STYLE_GO), "✅ "),
 							decor.Name(" ] "),
-							decor.AverageSpeed(decor.UnitKiB, "% .2f"),
+							decor.AverageSpeed(decor.SizeB1024(0), "% .2f", decor.WCSyncWidth),
 						),
 					)
 					// create proxy reader
